//
//  SlideShowScene.cpp
//  SlideShow0
//
//  Created by Heinrich Hussmann on 13.04.16.
//
//

#include "SlideShowScene.hpp"
#include <array>

using namespace cocos2d;

const int NUM_PICS = 4; //number of available slides
const int INTERVAL = 4; //interval for slide change, in seconds
const int BORDER = 30;  //size of framing border in design pixels
const Color4F bkgColor = Color4F(255/255.0, 228/255.0, 95/255.0, 1); // Background color (yellowish)

std::array<std::string, NUM_PICS> picFiles = {"frog.jpg","cows.jpg","elephant.jpg","tiger.jpg"};
// Traditional C style would be std::string gPicFiles[NUM_PICS]= {"frog.jpg","cows.jpg","elephant.jpg","tiger.jpg"};

Size visibleSize;
Size imageSpriteSize;
float originXImg;
float originYImg;

Scene* SlideShowScene::createScene()
{
    // 'scene' is an autorelease object
    auto scene = Scene::create();
    
    // 'layer' is an autorelease object
    auto layer = SlideShowScene::create();
    
    // Add layer as a child to scene
    scene->addChild(layer);
    
    // Return the scene
    return scene;
}

// initialize instance
bool SlideShowScene::init()
{
    // super init first
    if ( !Layer::init() )
    {
        return false;
    }
    
    // Initialize variables
    visibleSize = Director::getInstance()->getVisibleSize();
    Vec2 origin = Director::getInstance()->getVisibleOrigin();
    picIndex = 0;
    
    // Create DrawNode for image frame rectangle
    imageFrame = DrawNode::create();
    this->addChild(imageFrame);
    
    // Create sprite for images
    imageSprite = Sprite::create();
    this->addChild(imageSprite);
    
    // Preload first image and determine image size
    imageSprite->setTexture(picFiles[picIndex]);
    imageSpriteSize = imageSprite->getContentSize();
    
    // Position the sprite at the center of the screen
    originXImg = origin.x + visibleSize.width/2;
    originYImg = origin.y + visibleSize.height/2;
    imageSprite->setPosition(Vec2(originXImg, originYImg));
    
    // Draw the border, based on the coordinates and sizes we have computed
    imageFrame->drawSolidRect(Vec2(originXImg-imageSpriteSize.width/2-BORDER, originYImg-imageSpriteSize.height/2-BORDER), Vec2(originXImg+imageSpriteSize.width/2+BORDER, originYImg+imageSpriteSize.height/2+BORDER),bkgColor);
    
    // schedule the update function to be called every INTERVAL seconds
    this->schedule(schedule_selector(SlideShowScene::update), INTERVAL);
    return true;
}

void SlideShowScene::update (float dt) {
    CCLOG("update called, dt = %f, picIndex = %i", dt, picIndex);
    // Increase picIndex and set image according to picIndex
    picIndex = (picIndex+1) % NUM_PICS;
    imageSprite->setTexture(picFiles[picIndex]);
}

